summaryrefslogtreecommitdiff
path: root/include/uart.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/uart.h')
-rw-r--r--include/uart.h16
1 files changed, 11 insertions, 5 deletions
diff --git a/include/uart.h b/include/uart.h
index 05d4aee036..fa50645270 100644
--- a/include/uart.h
+++ b/include/uart.h
@@ -178,14 +178,20 @@ void uart_tx_stop(void);
int uart_tx_stopped(void);
/**
* Helper for UART processing.
*
- * Reads the input FIFO until empty, then fills the output FIFO until the
- * transmit buffer is empty or the FIFO full.
+ * Reads the input FIFO until empty. Intended to be called from the driver
+ * interrupt handler.
+ */
+void uart_process_input(void);
+
+/**
+ * Helper for processing UART output.
*
- * Designed to be called from the driver interrupt handler.
+ * Fills the output FIFO until the transmit buffer is empty or the FIFO full.
+ * Intended to be called from the driver interrupt handler.
*/
-void uart_process(void);
+void uart_process_output(void);
/*
* COMx functions
@@ -178,14 +178,20 @@ void uart_tx_stop(void);
int uart_tx_stopped(void);
/**
- * Helper for UART processing.
+ * Helper for processing UART input.
*